Metrics
=======

.. automodule:: ahrs.utils.metrics

Metrics in SO(3)
----------------

.. toctree::
   :maxdepth: 1

   metrics/chordal
   metrics/identity_deviation
   metrics/angular_distance
   metrics/qdist
   metrics/qeip
   metrics/qcip
   metrics/qad

Metrics in R(3)
---------------

.. toctree::
   :maxdepth: 1

   metrics/euclidean
   metrics/rmse
   metrics/rmse_matrices